pygerber.parser.blender.apertures namespace
===========================================

.. py:module:: pygerber.parser.blender.apertures

Submodules
----------

.. toctree::
   :maxdepth: 4

   pygerber.parser.blender.apertures.arc_mixin
   pygerber.parser.blender.apertures.circle
   pygerber.parser.blender.apertures.custom
   pygerber.parser.blender.apertures.flash_mixin
   pygerber.parser.blender.apertures.obround
   pygerber.parser.blender.apertures.polygon
   pygerber.parser.blender.apertures.rectangle
   pygerber.parser.blender.apertures.region
   pygerber.parser.blender.apertures.util
